summaryrefslogtreecommitdiff
path: root/src/testing/test_exchange_api.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-03-12 10:53:49 +0100
committerChristian Grothoff <christian@grothoff.org>2020-03-12 10:53:49 +0100
commit8d5f42fe0cff134120e462c7e905403f7d38b9d6 (patch)
treeab4a42e87cff97d921aa2a439c80fb81405fc520 /src/testing/test_exchange_api.c
parentb91fcbb92f21db498214cba38ffd6e3fe886d95e (diff)
downloadexchange-8d5f42fe0cff134120e462c7e905403f7d38b9d6.tar.gz
exchange-8d5f42fe0cff134120e462c7e905403f7d38b9d6.tar.bz2
exchange-8d5f42fe0cff134120e462c7e905403f7d38b9d6.zip
add separate commands for closer/transfer steps, modify test cases to use new commands
Diffstat (limited to 'src/testing/test_exchange_api.c')
-rw-r--r--src/testing/test_exchange_api.c20
1 files changed, 13 insertions, 7 deletions
diff --git a/src/testing/test_exchange_api.c b/src/testing/test_exchange_api.c
index ba655d9b8..3f7a1aed8 100644
--- a/src/testing/test_exchange_api.c
+++ b/src/testing/test_exchange_api.c
@@ -65,13 +65,16 @@ static struct TALER_TESTING_BankConfiguration bc;
TALER_TESTING_cmd_exec_wirewatch (label, CONFIG_FILE)
/**
* Execute the taler-exchange-aggregator command with
* our configuration file.
*
* @param label label to use for the command.
*/
#define CMD_EXEC_AGGREGATOR(label) \
- TALER_TESTING_cmd_exec_aggregator (label, CONFIG_FILE)
+ TALER_TESTING_cmd_exec_aggregator (label "-aggregator", CONFIG_FILE), \
+ TALER_TESTING_cmd_exec_closer (label "-closer", CONFIG_FILE), \
+ TALER_TESTING_cmd_exec_transfer (label "-transfer", CONFIG_FILE)
+
/**
* Run wire transfer of funds from some user's account to the
@@ -547,7 +550,8 @@ run (void *cls,
* Run transfers. This will do the transfer as refund deadline
* was 0, except of course because the refund succeeded, the
* transfer should no longer be done.
- */CMD_EXEC_AGGREGATOR ("run-aggregator-3b"),
+ *///
+ CMD_EXEC_AGGREGATOR ("run-aggregator-3b"),
/* check that aggregator didn't do anything, as expected */
TALER_TESTING_cmd_check_bank_empty ("check-refund-fast-not-run"),
TALER_TESTING_cmd_end ()
@@ -621,8 +625,10 @@ run (void *cls,
TALER_TESTING_cmd_exec_wirewatch ("short-lived-aggregation",
CONFIG_FILE_EXPIRE_RESERVE_NOW),
- TALER_TESTING_cmd_exec_aggregator ("close-reserves",
- CONFIG_FILE_EXPIRE_RESERVE_NOW),
+ TALER_TESTING_cmd_exec_closer ("close-reserves",
+ CONFIG_FILE_EXPIRE_RESERVE_NOW),
+ TALER_TESTING_cmd_exec_transfer ("close-reserves-transfer",
+ CONFIG_FILE_EXPIRE_RESERVE_NOW),
TALER_TESTING_cmd_status ("short-lived-status",
"short-lived-reserve",
@@ -740,8 +746,8 @@ run (void *cls,
= TALER_TESTING_cmd_exec_wirewatch ("reserve-open-close-wirewatch",
CONFIG_FILE_EXPIRE_RESERVE_NOW);
reserve_open_close[(i * RESERVE_OPEN_CLOSE_CHUNK) + 2]
- = TALER_TESTING_cmd_exec_aggregator ("reserve-open-close-aggregation",
- CONFIG_FILE_EXPIRE_RESERVE_NOW);
+ = TALER_TESTING_cmd_exec_closer ("reserve-open-close-aggregation",
+ CONFIG_FILE_EXPIRE_RESERVE_NOW);
reserve_open_close[(i * RESERVE_OPEN_CLOSE_CHUNK) + 3]
= TALER_TESTING_cmd_status ("reserve-open-close-status",
"reserve-open-close-key",
@@ -65,13 +65,16 @@ static struct TALER_TESTING_BankConfiguration bc;
TALER_TESTING_cmd_exec_wirewatch (label, CONFIG_FILE)
/**
- * Execute the taler-exchange-aggregator command with
+ * Execute the taler-exchange-aggregator, closer and transfer commands with
* our configuration file.
*